@@ -1,11 +1,10 @@
-from typing import Dict, Optional, Union
+from typing import Dict, Optional
 
 import pydantic
 
 from classiq_interface.backend.backend_preferences import (
-    AwsBackendPreferences,
-    AzureBackendPreferences,
-    IBMBackendPreferences,
+    BackendPreferencesTypes,
+    backend_preferences_field,
 )
 from classiq_interface.combinatorial_optimization.encoding_types import EncodingType
 from classiq_interface.combinatorial_optimization.preferences import QAOAPreferences
@@ -22,15 +21,8 @@ class OptimizationProblem(pydantic.BaseModel):
         description="preferences for the VQE execution",
     )
     serialized_model: Optional[Dict] = None
-    backend_preferences: Union[
-        AzureBackendPreferences, IBMBackendPreferences, AwsBackendPreferences
-    ] = pydantic.Field(
-        default_factory=lambda: IBMBackendPreferences(
-            backend_service_provider="IBMQ", backend_name="aer_simulator"
-        ),
-        description="Preferences for the requested backend to run the quantum circuit.",
-    )
+    backend_preferences: BackendPreferencesTypes = backend_preferences_field()
     encoding_type: Optional[EncodingType] = pydantic.Field(
-        default_factory=EncodingType.BINARY,
+        default=EncodingType.BINARY,
         description="encoding scheme for integer variables",
     )
