@@ -27,10 +27,10 @@ class FinanceFunctionInput(pydantic.BaseModel):
     f: Union[str, KnownFunctions] = pydantic.Field(
         description="A callable function to solve the model"
     )
-    variable: Optional[str] = pydantic.Field(
+    variable: str = pydantic.Field(
         default="x", description="Variable/s of the function"
     )
-    condition: Optional[FunctionCondition] = pydantic.Field(
+    condition: FunctionCondition = pydantic.Field(
         description="The condition for the function"
     )
     polynomial_degree: Optional[int] = pydantic.Field(
