@@ -2,6 +2,8 @@ from typing import List, Optional
 
 import pydantic
 
+from classiq_interface.helpers.custom_pydantic_types import pydanticProbabilityFloat
+
 
 class ModelParams(pydantic.BaseModel):
     loss: List[int] = pydantic.Field(
@@ -21,11 +23,11 @@ class GaussianModelInput(ModelParams):
     normal_max_value: float = pydantic.Field(
         description="Min/max value to truncate the " "latent normal random variable Z"
     )
-    default_probabilities: List[pydantic.confloat(ge=0, le=1)] = pydantic.Field(
+    default_probabilities: List[pydanticProbabilityFloat] = pydantic.Field(
         description="default probabilities for each asset"
     )
 
-    rhos: List[pydantic.confloat(gt=0)] = pydantic.Field(
+    rhos: List[pydantic.PositiveFloat] = pydantic.Field(
         description="Sensitivities of default probability of assets "
         "with respect to Z (1/sigma(Z))"
     )
@@ -33,3 +35,7 @@ class GaussianModelInput(ModelParams):
     @property
     def num_model_qubits(self):
         return len(self.rhos)
+
+    @property
+    def distribution_range(self):
+        return [0, sum(self.loss)]
