@@ -1,8 +1,9 @@
-from enum import Enum
-from typing import Any, Dict, Generic, List, Literal, Optional, Tuple, TypeVar, Union
+from typing import Any, Dict, Generic, List, Optional, Tuple, TypeVar, Union
 
 import pydantic
+from pydantic import BaseModel
 from pydantic.generics import GenericModel
+from typing_extensions import Literal
 
 from classiq_interface.generator.arith.arithmetic import DEFAULT_OUT_NAME
 from classiq_interface.generator.arith.fix_point_number import FixPointNumber
@@ -11,6 +12,7 @@ from classiq_interface.generator.function_params import FunctionParams
 
 DEFAULT_RIGHT_ARG_NAME = "right_arg"
 DEFAULT_LEFT_ARG_NAME = "left_arg"
+DEFAULT_GARBAGE_OUT_NAME = "deleted_qubits"
 LeftDataT = TypeVar("LeftDataT")
 RightDataT = TypeVar("RightDataT")
 Numeric = (float, int)
@@ -34,32 +36,38 @@ class BinaryOpParams(GenericModel, FunctionParams, Generic[LeftDataT, RightDataT
             right_arg.name = DEFAULT_RIGHT_ARG_NAME
         return right_arg
 
-    @pydantic.root_validator()
+    @pydantic.root_validator(pre=True)
     def validate_one_is_register(cls, values):
-        if isinstance(values.get("left_arg"), Numeric) and isinstance(
-            values.get("right_arg"), Numeric
-        ):
+        left_arg = values.get("left_arg")
+        right_arg = values.get("right_arg")
+        if isinstance(left_arg, Numeric) and isinstance(right_arg, Numeric):
             raise ValueError("One argument must be a register")
+        if left_arg is right_arg and isinstance(left_arg, BaseModel):
+            # In case both arguments refer to the same object, copy it.
+            # This prevents changes performed on one argument to affect the other.
+            values["right_arg"] = left_arg.copy(deep=True)
         return values
 
-    def create_io_enums(self):
-        self._create_input_enum()
-        self._create_output_enum()
+    def _create_io_names(self):
+        self._create_input_names()
+        self._create_output_names()
 
-    def _create_input_enum(self):
-        input_name_dict = self._input_register_name_dict(
-            [self.left_arg, self.right_arg]
+    def _create_input_names(self) -> None:
+        input_name_list = self._input_register_name_list(
+            [self.left_arg, self.right_arg, getattr(self, "target", None)]
         )
-        assert input_name_dict, "At least one argument should be a register"
-        self._input_enum = Enum("BinaryOpInputs", input_name_dict)
+        assert input_name_list, "At least one argument should be a register"
+        self._input_names = input_name_list
 
-    def _create_output_enum(self):
-        output_name_dict: Dict[str, str] = self._carried_inputs_name_dict()
-        output_name_dict[self.output_name] = self.output_name
-        self._output_enum = Enum("BinaryOpOutputs", output_name_dict)
+    def _create_output_names(self) -> None:
+        output_name_list: List[str] = self._carried_inputs_name_dict()
+        output_name_list.append(self.output_name)
+        if hasattr(self, "garbage_output_name"):
+            output_name_list.append(self.garbage_output_name)  # type: ignore[attr-defined]
+        self._output_names = output_name_list
 
-    def _carried_inputs_name_dict(self) -> Dict[str, str]:
-        return self._input_register_name_dict(list(self._carried_arguments()))
+    def _carried_inputs_name_dict(self) -> List[str]:
+        return self._input_register_name_list(list(self._carried_arguments()))
 
     def _carried_arguments(self) -> Tuple[Optional[LeftDataT], Optional[RightDataT]]:
         if getattr(self, "inplace", False):
@@ -70,12 +78,12 @@ class BinaryOpParams(GenericModel, FunctionParams, Generic[LeftDataT, RightDataT
         return self.left_arg, self.right_arg
 
     @staticmethod
-    def _input_register_name_dict(possible_register_args: List[Any]) -> Dict[str, str]:
-        name_dict: Dict[str, str] = dict()
-        for arg in possible_register_args:
-            if isinstance(arg, RegisterUserInput) and arg.name:
-                name_dict[arg.name] = arg.name
-        return name_dict
+    def _input_register_name_list(possible_register_args: List[Any]) -> List[str]:
+        return [
+            arg.name
+            for arg in possible_register_args
+            if isinstance(arg, RegisterUserInput) and arg.name
+        ]
 
     class Config:
         arbitrary_types_allowed = True
@@ -140,6 +148,20 @@ class Multiplier(BinaryOpWithFloatInputs):
 class Comparator(BinaryOpWithFloatInputs):
     output_size: Literal[1] = 1
     _include_equal: bool = pydantic.PrivateAttr(default=True)
+    target: Optional[RegisterUserInput]
+
+    @pydantic.validator("target", always=True)
+    def _validate_target(
+        cls, target: Optional[RegisterUserInput], values: Dict[str, Any]
+    ) -> Optional[RegisterUserInput]:
+        if target:
+            cls._assert_boolean_register(target)
+            target.name = (
+                target.name
+                if target.name
+                else values.get("output_name", DEFAULT_OUT_NAME)
+            )
+        return target
 
 
 class Equal(Comparator):
@@ -166,19 +188,32 @@ class LessEqual(Comparator):
     pass
 
 
-class BinaryOpWithLeftRegRightInt(
-    BinaryOpParams[RegisterUserInput, pydantic.PositiveInt]
-):
+class Extremum(BinaryOpWithFloatInputs):
+    _is_min: bool = pydantic.PrivateAttr(default=True)
+
+
+class Min(Extremum):
     pass
 
 
+class Max(Extremum):
+    pass
+
+
+class BinaryOpWithLeftRegRightInt(
+    BinaryOpParams[RegisterUserInput, pydantic.NonNegativeInt]
+):
+    inplace: Literal[True] = True
+
+
 class LShift(BinaryOpWithLeftRegRightInt):
     pass
 
 
 class RShift(BinaryOpWithLeftRegRightInt):
     use_arithmetic_bit_shift: bool = True
+    garbage_output_name: str = DEFAULT_GARBAGE_OUT_NAME
 
 
 class CyclicShift(BinaryOpParams[RegisterUserInput, int]):
-    pass
+    inplace: Literal[True] = True
