@@ -14,11 +14,14 @@ from classiq_interface.generator.arith.binary_ops import (
     LessEqual,
     LessThan,
     LShift,
+    Max,
+    Min,
     Multiplier,
     NotEqual,
     RShift,
     Subtractor,
 )
+from classiq_interface.generator.arith.logical_ops import LogicalAnd, LogicalOr
 from classiq_interface.generator.arith.unary_ops import BitwiseInvert, Negation
 from classiq_interface.generator.credit_risk_example.cdf_comparator import CDFComparator
 from classiq_interface.generator.credit_risk_example.linear_gci import LinearGCI
@@ -28,6 +31,7 @@ from classiq_interface.generator.entangler_params import (
     HypercubeEntangler,
     TwoDimensionalEntangler,
 )
+from classiq_interface.generator.exponentiation import Exponentiation
 from classiq_interface.generator.finance import Finance, FinanceModels, FinancePayoff
 from classiq_interface.generator.function_params import FunctionParams
 from classiq_interface.generator.grover_operator import GroverOperator
@@ -35,9 +39,9 @@ from classiq_interface.generator.hadamard_amp_load import HadamardAmpLoad
 from classiq_interface.generator.hardware_efficient_ansatz import (
     HardwareEfficientAnsatz,
 )
+from classiq_interface.generator.hartree_fock import HartreeFock
 from classiq_interface.generator.linear_pauli_rotations import LinearPauliRotations
 from classiq_interface.generator.mcx import Mcx
-from classiq_interface.generator.qaoa_ansatz import QaoaAnsatz
 from classiq_interface.generator.qft import QFT
 from classiq_interface.generator.sparse_amp_load import SparseAmpLoad
 from classiq_interface.generator.standard_gates.standard_gates_param_list import (
@@ -45,14 +49,12 @@ from classiq_interface.generator.standard_gates.standard_gates_param_list import
 )
 from classiq_interface.generator.state_preparation import StatePreparation
 from classiq_interface.generator.state_propagator import StatePropagator
+from classiq_interface.generator.ucc import UCC
 from classiq_interface.generator.unitary_gate import UnitaryGate
 from classiq_interface.generator.user_defined_function_params import CustomFunction
-from classiq_interface.generator.vqe_ansatz import VQEAnsatz
 
 _function_param_list = {
     StatePreparation,
-    VQEAnsatz,
-    QaoaAnsatz,
     StatePropagator,
     QFT,
     BitwiseAnd,
@@ -69,6 +71,8 @@ _function_param_list = {
     LessThan,
     LessEqual,
     Negation,
+    LogicalAnd,
+    LogicalOr,
     Subtractor,
     RShift,
     LShift,
@@ -92,6 +96,11 @@ _function_param_list = {
     Multiplier,
     LinearGCI,
     CDFComparator,
+    HartreeFock,
+    UCC,
+    Min,
+    Max,
+    Exponentiation,
 }
 
 
