@@ -1,7 +1,7 @@
 from typing import Optional
 
 from classiq_interface.generator.arith.arithmetic import ArithmeticOracle
-from classiq_interface.generator.function_params import FunctionParams
+from classiq_interface.generator.function_params import IO, FunctionParams
 from classiq_interface.generator.state_preparation import StatePreparation
 
 
@@ -10,9 +10,9 @@ class GroverOperator(FunctionParams):
     state_preparation: Optional[StatePreparation] = None
     diffuser: Optional[str] = None
 
-    def create_io_enums(self):
-        self._input_enum = self.oracle._input_enum
-        self._output_enum = self.oracle._input_enum
+    def _create_io_names(self) -> None:
+        self._input_names = self.oracle.get_io_names(IO.Input)
+        self._output_names = self.oracle.get_io_names(IO.Input)
 
     class Config:
         extra = "forbid"
