@@ -81,8 +81,9 @@ class SynthesisMetrics(pydantic.BaseModel):
         return self.function_metrics.__len__()
 
     def __iter__(self):
-        for function_name in self.topological_sort:
-            yield self[function_name]
+        if not self.topological_sort:
+            return
+        yield from (self[function_name] for function_name in self.topological_sort)
 
     def _update_wires(self, qubit_absolute_indexes: Dict[str, List[int]]):
         for fm in self.function_metrics:
